pub struct PublishedCheckpoint {
pub location: Location,
pub sequence_number: u64,
}Expand description
Writer publication point that is known to be durable in Store.
Fields
location: LocationInclusive maximum QMDB Location authorized by this checkpoint.
sequence_number: u64Store sequence number at which the checkpoint became visible.